@@ -100,7 +100,7 @@ class RequestMiddleware(palp.RequestMiddleware):
         请求结果记录（在 spider 结束时调用）
 
         :param spider:
-        :param record:
+        :param record: {'all': 0, 'failed': 0, 'succeed': 0} 样式的字典
         :return:
         """
         logger.info("{} 执行完毕，请求量统计：{}", spider.spider_name, record)
